@@ -20,9 +20,7 @@ class ProjectModel(BaseModel):
     tags: str
 
 
-class ApplicationModel(BaseModel):
-    id: UUID
-    mode: str
+class AppModel(BaseModel):
     name: str
     title: str
     caption: str
@@ -35,9 +33,19 @@ class ApplicationModel(BaseModel):
     icon_url: str
     icon_light_url: str
     icon_dark_url: str
-    domain: str
     tags: str
     colour: str
+    
+
+class ApplicationModel(AppModel):
+    id: UUID
+    mode: str
+    domain: str
+    cleint_id: str
+    client_secret: str
+    client_scope: str
+    redirect_uri: str
+    response_type: str
     is_active: bool
     project: ProjectModel
-    modules: Optional[List[ModuleModel]]
+    modules: Optional[List[ModuleModel]]
\ No newline at end of file
