@@ -11,9 +11,6 @@ from .user_model import UserModel
 
 
 class ContextModel(BaseModel):
-    id: UUID
-    project: ProjectModel
-    mode: str
     name: str
     title: str
     caption: str
@@ -28,7 +25,6 @@ class ContextModel(BaseModel):
     icon_dark_url: str
     tags: str
     colour: str
-    is_active: bool
     location: LocationModel
     nation: NationModel
     user: Optional[UserModel] = None
