@@ -21,7 +21,7 @@ class NationService:
     def _get_from_api(self) -> Optional[NationModel]:
         try:
             client = NkunyimApiClient(req=self.req, name=settings.PLACE_SERVICE)
-            response = client.get(path=f"/api/nations/?code={self.code.upper()}")
+            response = client.get(path=f"/nations/?code={self.code.upper()}")
             if not response.ok:
                 # log error
                 return None
